@@ -362,8 +362,7 @@ parse_itemset(PyObject* value, AuthorizationItemSet* itemset)
             return 0;
         }
         itemset->count = PyTuple_GET_SIZE(seq);
-        itemset->items =
-            PyMem_Malloc(sizeof(AuthorizationItem) * PyTuple_GET_SIZE(seq));
+        itemset->items = PyMem_Malloc(sizeof(AuthorizationItem) * PyTuple_GET_SIZE(seq));
         if (itemset->items == NULL) {
             PyErr_NoMemory();
             return 0;
@@ -800,7 +799,8 @@ static PyMethodDef mod_methods[] = {
     {0, 0, 0, 0} /* sentinel */
 };
 
-static int mod_exec_module(PyObject* m)
+static int
+mod_exec_module(PyObject* m)
 {
     if (PyObjC_ImportAPI(m) == -1)
         return -1;
@@ -808,50 +808,45 @@ static int mod_exec_module(PyObject* m)
     return 0;
 }
 
-
 static struct PyModuleDef_Slot mod_slots[] = {
-    {
-        .slot = Py_mod_exec,
-        .value = (void*)mod_exec_module
-    },
+    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
 #if PY_VERSION_HEX >= 0x030c0000
     {
         /* This extension does not use the CPython API other than initializing
          * the module, hence is safe with subinterpreters and per-interpreter
          * GILs
          */
-        .slot = Py_mod_multiple_interpreters,
+        .slot  = Py_mod_multiple_interpreters,
         .value = Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED,
     },
 #endif
 #if PY_VERSION_HEX >= 0x030d0000
     {
         /* The code in this extension should be safe to use without the GIL */
-        .slot = Py_mod_gil,
+        .slot  = Py_mod_gil,
         .value = Py_MOD_GIL_NOT_USED,
     },
 #endif
-    {  /* Sentinel */
-        .slot = 0,
-        .value = 0
-    }
-};
+    {/* Sentinel */
+     .slot  = 0,
+     .value = 0}};
 
 static struct PyModuleDef mod_module = {
-    .m_base = PyModuleDef_HEAD_INIT,
-    .m_name = "_Security",
-    .m_doc = NULL,
-    .m_size = 0,
-    .m_methods = mod_methods,
-    .m_slots = mod_slots,
+    .m_base     = PyModuleDef_HEAD_INIT,
+    .m_name     = "_Security",
+    .m_doc      = NULL,
+    .m_size     = 0,
+    .m_methods  = mod_methods,
+    .m_slots    = mod_slots,
     .m_traverse = NULL,
-    .m_clear = NULL,
-    .m_free = NULL,
+    .m_clear    = NULL,
+    .m_free     = NULL,
 };
 
 PyObject* PyInit__Security(void);
 
-PyObject* __attribute__((__visibility__("default"))) PyInit__Security(void)
+PyObject* __attribute__((__visibility__("default")))
+PyInit__Security(void)
 {
     return PyModuleDef_Init(&mod_module);
 }
